==> onecx-quarkus-it-security-0.18.0-sources.jar: gen/org/tkit/onecx/quarkus/security/example/model/RoleDTO.java <==
package gen.org.tkit.onecx.quarkus.security.example.model;

import com.fasterxml.jackson.annotation.JsonTypeName;
import java.time.OffsetDateTime;
import java.io.Serializable;
import jakarta.validation.constraints.*;
import jakarta.validation.Valid;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.annotation.JsonTypeName;



@org.eclipse.microprofile.openapi.annotations.media.Schema(description="")
@JsonTypeName("Role")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaJAXRSSpecServerCodegen", date = "2024-05-02T09:55:34.852473576Z[Etc/UTC]", comments = "Generator version: 7.5.0")
public class RoleDTO  implements Serializable {
  private Integer modificationCount;
  private OffsetDateTime creationDate;
  private String creationUser;
  private OffsetDateTime modificationDate;
  private String modificationUser;
  private String id;
  private String name;
  private String description;

  /**
   **/
  public RoleDTO modificationCount(Integer modificationCount) {
    this.modificationCount = modificationCount;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("modificationCount")
  public Integer getModificationCount() {
    return modificationCount;
  }

  @JsonProperty("modificationCount")
  public void setModificationCount(Integer modificationCount) {
    this.modificationCount = modificationCount;
  }

  /**
   **/
  public RoleDTO creationDate(OffsetDateTime creationDate) {
    this.creationDate = creationDate;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(example = "2022-03-10T12:15:50-04:00", description = "")
  @JsonProperty("creationDate")
  @Valid public OffsetDateTime getCreationDate() {
    return creationDate;
  }

  @JsonProperty("creationDate")
  public void setCreationDate(OffsetDateTime creationDate) {
    this.creationDate = creationDate;
  }

  /**
   **/
  public RoleDTO creationUser(String creationUser) {
    this.creationUser = creationUser;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("creationUser")
  public String getCreationUser() {
    return creationUser;
  }

  @JsonProperty("creationUser")
  public void setCreationUser(String creationUser) {
    this.creationUser = creationUser;
  }

  /**
   **/
  public RoleDTO modificationDate(OffsetDateTime modificationDate) {
    this.modificationDate = modificationDate;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(example = "2022-03-10T12:15:50-04:00", description = "")
  @JsonProperty("modificationDate")
  @Valid public OffsetDateTime getModificationDate() {
    return modificationDate;
  }

  @JsonProperty("modificationDate")
  public void setModificationDate(OffsetDateTime modificationDate) {
    this.modificationDate = modificationDate;
  }

  /**
   **/
  public RoleDTO modificationUser(String modificationUser) {
    this.modificationUser = modificationUser;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("modificationUser")
  public String getModificationUser() {
    return modificationUser;
  }

  @JsonProperty("modificationUser")
  public void setModificationUser(String modificationUser) {
    this.modificationUser = modificationUser;
  }

  /**
   **/
  public RoleDTO id(String id) {
    this.id = id;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("id")
  public String getId() {
    return id;
  }

  @JsonProperty("id")
  public void setId(String id) {
    this.id = id;
  }

  /**
   **/
  public RoleDTO name(String name) {
    this.name = name;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("name")
  public String getName() {
    return name;
  }

  @JsonProperty("name")
  public void setName(String name) {
    this.name = name;
  }

  /**
   **/
  public RoleDTO description(String description) {
    this.description = description;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("description")
  public String getDescription() {
    return description;
  }

  @JsonProperty("description")
  public void setDescription(String description) {
    this.description = description;
  }


  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    RoleDTO role = (RoleDTO) o;
    return Objects.equals(this.modificationCount, role.modificationCount) &&
        Objects.equals(this.creationDate, role.creationDate) &&
        Objects.equals(this.creationUser, role.creationUser) &&
        Objects.equals(this.modificationDate, role.modificationDate) &&
        Objects.equals(this.modificationUser, role.modificationUser) &&
        Objects.equals(this.id, role.id) &&
        Objects.equals(this.name, role.name) &&
        Objects.equals(this.description, role.description);
  }

  @Override
  public int hashCode() {
    return Objects.hash(modificationCount, creationDate, creationUser, modificationDate, modificationUser, id, name, description);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class RoleDTO {\n");
    
    sb.append("    modificationCount: ").append(toIndentedString(modificationCount)).append("\n");
    sb.append("    creationDate: ").append(toIndentedString(creationDate)).append("\n");
    sb.append("    creationUser: ").append(toIndentedString(creationUser)).append("\n");
    sb.append("    modificationDate: ").append(toIndentedString(modificationDate)).append("\n");
    sb.append("    modificationUser: ").append(toIndentedString(modificationUser)).append("\n");
    sb.append("    id: ").append(toIndentedString(id)).append("\n");
    sb.append("    name: ").append(toIndentedString(name)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }


}

==> onecx-quarkus-it-security-0.19.0-sources.jar: gen/org/tkit/onecx/quarkus/security/example/model/RoleDTO.java <==
package gen.org.tkit.onecx.quarkus.security.example.model;

import com.fasterxml.jackson.annotation.JsonTypeName;
import java.time.OffsetDateTime;
import java.io.Serializable;
import jakarta.validation.constraints.*;
import jakarta.validation.Valid;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.annotation.JsonTypeName;



@org.eclipse.microprofile.openapi.annotations.media.Schema(description="")
@JsonTypeName("Role")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaJAXRSSpecServerCodegen", date = "2024-06-07T11:57:45.219534244Z[Etc/UTC]", comments = "Generator version: 7.6.0")
public class RoleDTO  implements Serializable {
  private Integer modificationCount;
  private OffsetDateTime creationDate;
  private String creationUser;
  private OffsetDateTime modificationDate;
  private String modificationUser;
  private String id;
  private String name;
  private String description;

  /**
   **/
  public RoleDTO modificationCount(Integer modificationCount) {
    this.modificationCount = modificationCount;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("modificationCount")
  public Integer getModificationCount() {
    return modificationCount;
  }

  @JsonProperty("modificationCount")
  public void setModificationCount(Integer modificationCount) {
    this.modificationCount = modificationCount;
  }

  /**
   **/
  public RoleDTO creationDate(OffsetDateTime creationDate) {
    this.creationDate = creationDate;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(example = "2022-03-10T12:15:50-04:00", description = "")
  @JsonProperty("creationDate")
  public OffsetDateTime getCreationDate() {
    return creationDate;
  }

  @JsonProperty("creationDate")
  public void setCreationDate(OffsetDateTime creationDate) {
    this.creationDate = creationDate;
  }

  /**
   **/
  public RoleDTO creationUser(String creationUser) {
    this.creationUser = creationUser;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("creationUser")
  public String getCreationUser() {
    return creationUser;
  }

  @JsonProperty("creationUser")
  public void setCreationUser(String creationUser) {
    this.creationUser = creationUser;
  }

  /**
   **/
  public RoleDTO modificationDate(OffsetDateTime modificationDate) {
    this.modificationDate = modificationDate;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(example = "2022-03-10T12:15:50-04:00", description = "")
  @JsonProperty("modificationDate")
  public OffsetDateTime getModificationDate() {
    return modificationDate;
  }

  @JsonProperty("modificationDate")
  public void setModificationDate(OffsetDateTime modificationDate) {
    this.modificationDate = modificationDate;
  }

  /**
   **/
  public RoleDTO modificationUser(String modificationUser) {
    this.modificationUser = modificationUser;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("modificationUser")
  public String getModificationUser() {
    return modificationUser;
  }

  @JsonProperty("modificationUser")
  public void setModificationUser(String modificationUser) {
    this.modificationUser = modificationUser;
  }

  /**
   **/
  public RoleDTO id(String id) {
    this.id = id;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("id")
  public String getId() {
    return id;
  }

  @JsonProperty("id")
  public void setId(String id) {
    this.id = id;
  }

  /**
   **/
  public RoleDTO name(String name) {
    this.name = name;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("name")
  public String getName() {
    return name;
  }

  @JsonProperty("name")
  public void setName(String name) {
    this.name = name;
  }

  /**
   **/
  public RoleDTO description(String description) {
    this.description = description;
    return this;
  }

  
  @org.eclipse.microprofile.openapi.annotations.media.Schema(description = "")
  @JsonProperty("description")
  public String getDescription() {
    return description;
  }

  @JsonProperty("description")
  public void setDescription(String description) {
    this.description = description;
  }


  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    RoleDTO role = (RoleDTO) o;
    return Objects.equals(this.modificationCount, role.modificationCount) &&
        Objects.equals(this.creationDate, role.creationDate) &&
        Objects.equals(this.creationUser, role.creationUser) &&
        Objects.equals(this.modificationDate, role.modificationDate) &&
        Objects.equals(this.modificationUser, role.modificationUser) &&
        Objects.equals(this.id, role.id) &&
        Objects.equals(this.name, role.name) &&
        Objects.equals(this.description, role.description);
  }

  @Override
  public int hashCode() {
    return Objects.hash(modificationCount, creationDate, creationUser, modificationDate, modificationUser, id, name, description);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class RoleDTO {\n");
    
    sb.append("    modificationCount: ").append(toIndentedString(modificationCount)).append("\n");
    sb.append("    creationDate: ").append(toIndentedString(creationDate)).append("\n");
    sb.append("    creationUser: ").append(toIndentedString(creationUser)).append("\n");
    sb.append("    modificationDate: ").append(toIndentedString(modificationDate)).append("\n");
    sb.append("    modificationUser: ").append(toIndentedString(modificationUser)).append("\n");
    sb.append("    id: ").append(toIndentedString(id)).append("\n");
    sb.append("    name: ").append(toIndentedString(name)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }


}
